/**
 * Organization: Pacotei
 * Github: https://github.com/orgs/pacotei
 * Author: Marcus Pereira
 * E-mail: oi@pacotei.xyz
 */

//  Set Config for Vue
Vue.options.delimiters = ["#{", "}"];
